==> genometools-1.3.4.tar.gz: genometools-1.3.4/src/match/idxlocalidp.h <==
/*
  Copyright (c) 2009 Stefan Kurtz <kurtz@zbh.uni-hamburg.de>
  Copyright (c) 2009 Center for Bioinformatics, University of Hamburg

  Permission to use, copy, modify, and distribute this software for any
  purpose with or without fee is hereby granted, provided that the above
  copyright notice and this permission notice appear in all copies.

  THE SOFTWARE IS PROVIDED "AS IS" AND THE AUTHOR DISCLAIMS ALL WARRANTIES
  WITH REGARD TO THIS SOFTWARE INCLUDING ALL IMPLIED WARRANTIES OF
  MERCHANTABILITY AND FITNESS. IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR
  ANY SPECIAL, DIRECT, INDIRECT, OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES
  WHATSOEVER RESULTING FROM LOSS OF USE, DATA OR PROFITS, WHETHER IN AN
  ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF
  OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
*/

#ifndef IDXLOCALIDP_H
#define IDXLOCALIDP_H
#include "core/symboldef.h"
#include "seqpos-def.h"
#include "absdfstrans-def.h"

const AbstractDfstransformer *locali_AbstractDfstransformer(void);

void reinitLocalitracebackstate(Limdfsconstinfo *lci,
                                Seqpos dbprefixlen,
                                unsigned long pprefixlen);

void processelemLocalitracebackstate(Limdfsconstinfo *lci,
                                     GtUchar currentchar,
                                     const void *aliasstate);

const void *completealignmentfromLocalitracebackstate(
                                      unsigned long *alignedquerylength,
                                      const Limdfsconstinfo *lci);

#endif

==> genometools-1.3.8.tar.gz: genometools-1.3.8/src/match/idxlocalidp.h <==
/*
  Copyright (c) 2009 Stefan Kurtz <kurtz@zbh.uni-hamburg.de>
  Copyright (c) 2009 Center for Bioinformatics, University of Hamburg

  Permission to use, copy, modify, and distribute this software for any
  purpose with or without fee is hereby granted, provided that the above
  copyright notice and this permission notice appear in all copies.

  THE SOFTWARE IS PROVIDED "AS IS" AND THE AUTHOR DISCLAIMS ALL WARRANTIES
  WITH REGARD TO THIS SOFTWARE INCLUDING ALL IMPLIED WARRANTIES OF
  MERCHANTABILITY AND FITNESS. IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR
  ANY SPECIAL, DIRECT, INDIRECT, OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES
  WHATSOEVER RESULTING FROM LOSS OF USE, DATA OR PROFITS, WHETHER IN AN
  ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF
  OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
*/

#ifndef IDXLOCALIDP_H
#define IDXLOCALIDP_H
#include "core/types_api.h"

#include "absdfstrans-def.h"

const AbstractDfstransformer *gt_locali_AbstractDfstransformer(void);

void gt_reinitLocalitracebackstate(Limdfsconstinfo *lci,
                                unsigned long dbprefixlen,
                                unsigned long pprefixlen);

void gt_processelemLocalitracebackstate(Limdfsconstinfo *lci,
                                     GtUchar currentchar,
                                     const void *aliasstate);

const void *gt_completealignmentfromLocalitracebackstate(
                                      unsigned long *alignedquerylength,
                                      const Limdfsconstinfo *lci);

#endif
